#!/usr/bin/perl

# Written by Roderick Groeneveld (c) 2012

use XML::LibXML;
use XML::LibXML::Iterator;
use POSIX qw(ceil);
use File::Basename;
use Data::Dumper;

my $numArgs = $#ARGV + 1;
#nprint("Processing $numArgs files.");

$inputfile = $ARGV[0];
$hosts_per_file = $ARGV[1];

if ($hosts_per_file < 100) { die("[ERROR] It's a bad idea to have less than 100 hosts per file."); }
my $hosts = `grep "</host>" $ARGV[0] | wc -l`;

$parser = XML::LibXML->new();
$output_doc = XML::LibXML::Document->new("1.0","UTF-8");
$doc = $parser->parse_file("$inputfile");

$output_node = $doc->firstChild()->cloneNode();
$output_node->addChild(XML::LibXML::Element->new("hosts"));

$curnode = $doc->firstChild->firstChild->nextSibling()->firstChild->nextSibling();
#print Dumper $curnode->toString();

$output_node->firstChild->addChild($curnode->cloneNode(1));

for ($count = 1; $count <= ceil($hosts/$hosts_per_file); $count++)
{
	$outputfile = "output/" . basename($inputfile) . "-$count.xml";
	open OUTPUTFILE, ">$outputfile" or processErr($!);

	$start = ($count-1) * $hosts_per_file + 1;
	$end = $count * $hosts_per_file;

	print "$start - $end \n\n";
	#next;

	$countint = 0;
  	while ($countint < $end - $start + 1){
		#if ($countint < $start) {$countint++;next};
		if (defined($curnode->nextSibling()->nextSibling))
		{
			$curnode = $curnode->nextSibling()->nextSibling;
			$output_node->firstChild->addChild($curnode->cloneNode(1));
			$countint++;
		}
		else {last;}
        	if ($countint > $end) {$countint++;last};
  	}

	print OUTPUTFILE $output_node->toString(1);
	close OUTPUTFILE;
	$output_node = $doc->firstChild()->cloneNode();
	$output_node->addChild(XML::LibXML::Element->new("hosts"));
	print "\n";
}

sub nprint
{
	my $msg = shift;
	print localtime() . " [INFO] $msg\n";
}

sub processErr
{
	my $msg = shift;
	print localtime() . " [ERROR] $msg\n";
	die("Fatal error.\n");
}

